@@ -39,7 +39,7 @@
 #include <X11/Xutil.h>
 
 #include "mozplugger.h"
-#include "mozplugger-child.h"
+#include "child.h"
 
 #define MAX_CONTROLS_WIDTH           300
 #define MAX_CONTROLS_HEIGHT          100
