@@ -43,7 +43,7 @@
 #include <sys/time.h>
 
 #include "mozplugger.h"
-#include "mozplugger-child.h"
+#include "child.h"
 
 /*****************************************************************************
  * Type declarations
