@@ -39,7 +39,7 @@
 #include <X11/Xutil.h>
 
 #include "mozplugger.h"
-#include "mozplugger-child.h"
+#include "child.h"
 
 #define MAX_BUTTON_SIZE           100
 #define DEFAULT_BUTTON_SIZE        20
