@@ -677,11 +677,12 @@ static int parse_flags(char **x, command_t *commandp)
 	  { "embed",            H_EMBED         },
 	  { "noembed",          H_NOEMBED       },
           { "links",            H_LINKS         },
-	  { "hidden",           H_HIDDEN        },
           { "controls",         H_CONTROLS      },
           { "swallow",          H_SWALLOW       },
           { "fmatch",           H_FMATCH        },
           { "autostart",        H_AUTOSTART     },
+          { "needs_xembed",     H_NEEDS_XEMBED  },
+	  { "hidden",           0               },  /* Deprecated */
 	  { NULL, 		0 		}
      };
 
@@ -1544,6 +1545,11 @@ static int find_command(data_t * const THIS, int streamOnly, const char * url)
 
      D("find_command...\n");
 
+     /* Reset any previous command we may have found */
+     THIS->command = 0;
+     THIS->cmd_flags = 0;
+     THIS->winname = 0;
+
      do_read_config();
 
      h = handlers;
@@ -1704,8 +1710,28 @@ NPError NPP_GetValue(void *instance, NPPVariable variable, void *value)
 	  break;
 
      case NPPVpluginNeedsXEmbed:
-          D("NPP_GetValue(NPPVpluginNeedsXEmbed), returned true\n"); 
-          *((NPBool *)value) = 1;
+          if (instance == 0)
+          {
+	       err = NPERR_GENERIC_ERROR;
+          }
+          else
+          {
+               data_t * this = ((NPP)instance)->pdata;
+               if(this == 0)
+               {
+	            err = NPERR_GENERIC_ERROR;
+               }
+               if((this->cmd_flags & H_NEEDS_XEMBED) != 0) 
+               {
+                    D("NPP_GetValue(NPPVpluginNeedsXEmbed), returned true\n"); 
+                    *((NPBool *)value) = 1;
+               }
+               else
+               {
+                    D("NPP_GetValue(NPPVpluginNeedsXEmbed), returned false\n"); 
+                    *((NPBool *)value) = 0;
+               }
+          }
           break; 
 
      default :
@@ -2004,6 +2030,11 @@ NPError NPP_New(NPMIMEType pluginType,
 
      if (url)
      {
+          if( !safeURL(url))
+          {
+	       return NPERR_GENERIC_ERROR;
+          }
+
           /* Mozilla does not support the following protocols directly and
            * so it never calls NPP_NewStream for these protocols */
 	  if(   (strncmp(url, "mms://", 6) == 0)        
@@ -2015,14 +2046,16 @@ NPError NPP_New(NPMIMEType pluginType,
 	  {
 	       D("Detected MMS -> url=%s\n", url);
 
-               if( !safeURL(url))
-               {
-	            return NPERR_GENERIC_ERROR;
-               }
-	       THIS->mms = url;
+               THIS->mms = url;
+
+               /* Find only those commands that have H_STREAM set */
+               find_command(THIS, 1, url);
 	  }
           else 
           {
+               /* Find those commands that have H_STREAM or not set */
+               find_command(THIS, 0, url);
+
                /* For protocols that Mozilla does support, sometimes
                 * the browser will call NPP_NewStream straight away, some
                 * times it wont (depends on the nature of the tag). So that
@@ -2226,6 +2259,10 @@ NPError NPP_NewStream(NPP instance,
 	  D("Replacing SRC with HREF... \n");
 	  stream->url = THIS->href;
      }
+     else
+     {
+          find_command(THIS, 0, stream->url);
+     }
 
      /* Extract from the URL the various additional information */
      parseURL(THIS, stream->url);
@@ -2246,34 +2283,25 @@ NPError NPP_NewStream(NPP instance,
             "for url %s\n", THIS->mimetype, type, stream->url);
           savedMimetype = THIS->mimetype;
           THIS->mimetype = strdup(type);
+
+          if(!find_command(THIS, 0, stream->url))
+          {
+                free(THIS->mimetype);
+                THIS->mimetype = savedMimetype;
+                find_command(THIS, 0, stream->url);
+          }
+          else
+          {
+              free(savedMimetype);
+          }
      }
 
-     /* Find a suitable command, fall back to savedMimeType if defined */
-     while(!find_command(THIS, 0, stream->url))
+     if(THIS->command == 0)
      {
-          if(savedMimetype)       /* Lets try the saved one */
-          {
-               free(THIS->mimetype);
-               THIS->mimetype = savedMimetype;
-               savedMimetype = NULL;
-          }
-          else 
-          {
-               if(errMsg)
-               {
-                    NPN_Status(instance, errMsg);
-                    errMsg = NULL;
-               }
-               else
-               {
-	            NPN_Status(instance, 
+	  NPN_Status(instance, 
                          "MozPlugger: No appropriate application found.");
-               }
-	       return NPERR_GENERIC_ERROR;
-          }
+	  return NPERR_GENERIC_ERROR;
      }
-     free(savedMimetype);     /* discard the saved Mime type */
-
 
      if ((THIS->cmd_flags & H_STREAM)
 	 && strncasecmp(stream->url, "file:", 5)
