@@ -53,18 +53,18 @@
 #define FIND_CACHE_SIZE   10
 
 /* Flags */
-#define H_LOOP          0x1
-#define H_DAEMON        0x2
-#define H_STREAM        0x4
-#define H_NOISY         0x8
-#define H_REPEATCOUNT   0x10
-#define H_EMBED         0x20
-#define H_NOEMBED       0x40
-#define H_IGNORE_ERRORS 0x80
-#define H_SWALLOW       0x100
-#define H_MAXASPECT     0x200
-#define H_FILL          0x400
-#define H_HIDDEN        0x800
+#define H_LOOP          0x0001
+#define H_DAEMON        0x0002
+#define H_STREAM        0x0004
+#define H_NOISY         0x0008
+#define H_REPEATCOUNT   0x0010
+#define H_EMBED         0x0020
+#define H_NOEMBED       0x0040
+#define H_IGNORE_ERRORS 0x0080
+#define H_SWALLOW       0x0100
+#define H_MAXASPECT     0x0200
+#define H_FILL          0x0400
+#define H_NEEDS_XEMBED  0x0800
 #define H_CONTROLS      0x1000
 #define H_LINKS         0x2000
 #define H_FMATCH        0x4000
